@@ -267,13 +267,16 @@ function genericPrintNoParens(path, options, print) {
         ]);
 
     case "MemberExpression":
+    case "OptionalMemberExpression":
         parts.push(path.call(print, "object"));
 
         var property = path.call(print, "property");
+        var optional = n.type === "OptionalMemberExpression";
+
         if (n.computed) {
-            parts.push("[", property, "]");
+            parts.push(optional ? "?.[" : "[", property, "]");
         } else {
-            parts.push(".", property);
+            parts.push(optional ? "?." : ".", property);
         }
 
         return concat(parts);
@@ -623,10 +626,17 @@ function genericPrintNoParens(path, options, print) {
         return concat(parts);
 
     case "CallExpression":
-        return concat([
-            path.call(print, "callee"),
-            printArgumentsList(path, options, print)
-        ]);
+    case "OptionalCallExpression":
+        var parts = [path.call(print, "callee")];
+
+        if (n.type === "OptionalCallExpression" &&
+            n.callee.type !== "OptionalMemberExpression") {
+            parts.push("?.");
+        }
+
+        parts.push(printArgumentsList(path, options, print));
+
+        return concat(parts);
 
     case "ObjectExpression":
     case "ObjectPattern":
@@ -1162,7 +1172,10 @@ function genericPrintNoParens(path, options, print) {
         var openingLines = path.call(print, openingPropName);
 
         if (n[openingPropName].selfClosing) {
-            assert.ok(!n[closingPropName]);
+            assert.ok(
+                !n[closingPropName],
+                "unexpected " + closingPropName + " element in self-closing " + n.type
+            );
             return openingLines;
         }
 
@@ -1386,9 +1399,11 @@ function genericPrintNoParens(path, options, print) {
     case "Declaration":
     case "Specifier":
     case "NamedSpecifier":
-    case "Comment": // Supertype of Block and Line.
+    case "Comment": // Supertype of Block and Line
+    case "Flow": // Supertype of all Flow AST node types
+    case "FlowType": // Supertype of all Flow types
+    case "FlowPredicate": // Supertype of InferredPredicate and DeclaredPredicate
     case "MemberTypeAnnotation": // Flow
-    case "TupleTypeAnnotation": // Flow
     case "Type": // Flow
     case "TSHasOptionalTypeParameters":
     case "TSHasOptionalTypeAnnotation":
@@ -1434,6 +1449,54 @@ function genericPrintNoParens(path, options, print) {
             "[]"
         ]);
 
+    case "TupleTypeAnnotation":
+        var printed = path.map(print, "types");
+        var joined = fromString(", ").join(printed);
+        var oneLine = joined.getLineLength(1) <= options.wrapColumn;
+        if (oneLine) {
+          if (options.arrayBracketSpacing) {
+            parts.push("[ ");
+          } else {
+            parts.push("[");
+          }
+        } else {
+          parts.push("[\n");
+        }
+
+        path.each(function(elemPath) {
+            var i = elemPath.getName();
+            var elem = elemPath.getValue();
+            if (!elem) {
+                // If the array expression ends with a hole, that hole
+                // will be ignored by the interpreter, but if it ends with
+                // two (or more) holes, we need to write out two (or more)
+                // commas so that the resulting code is interpreted with
+                // both (all) of the holes.
+                parts.push(",");
+            } else {
+                var lines = printed[i];
+                if (oneLine) {
+                    if (i > 0)
+                        parts.push(" ");
+                } else {
+                    lines = lines.indent(options.tabWidth);
+                }
+                parts.push(lines);
+                if (i < n.types.length - 1 || (!oneLine && util.isTrailingCommaEnabled(options, "arrays")))
+                    parts.push(",");
+                if (!oneLine)
+                    parts.push("\n");
+            }
+        }, "types");
+
+        if (oneLine && options.arrayBracketSpacing) {
+          parts.push(" ]");
+        } else {
+          parts.push("]");
+        }
+
+        return concat(parts);
+
     case "BooleanTypeAnnotation":
         return fromString("boolean", options);
 
@@ -1484,6 +1547,16 @@ function genericPrintNoParens(path, options, print) {
             printExportDeclaration(path, options, print)
         ]);
 
+    case "InferredPredicate":
+        return fromString("%checks", options);
+
+    case "DeclaredPredicate":
+        return concat([
+            "%checks(",
+            path.call(print, "value"),
+            ")"
+        ]);
+
     case "FunctionTypeAnnotation":
         // FunctionTypeAnnotation is ambiguous:
         // declare function(a: B): void; OR
@@ -2059,6 +2132,7 @@ function genericPrintNoParens(path, options, print) {
 
     case "TSTypeAliasDeclaration":
         return concat([
+            n.declare ? "declare " : "",
             "type ",
             path.call(print, "id"),
             path.call(print, "typeParameters"),
@@ -2586,6 +2660,49 @@ function printExportDeclaration(path, options, print) {
         if (decl.specifiers.length === 1 &&
             decl.specifiers[0].type === "ExportBatchSpecifier") {
             parts.push("*");
+        } else if (decl.specifiers[0].type === 'ExportDefaultSpecifier') {
+            const unbracedSpecifiers = [];
+            const bracedSpecifiers = [];
+
+            path.each(function (specifierPath) {
+                const spec = specifierPath.getValue();
+                if (spec.type === "ExportDefaultSpecifier") {
+                    unbracedSpecifiers.push(print(specifierPath));
+                } else {
+                    bracedSpecifiers.push(print(specifierPath));
+                }
+            }, "specifiers");
+
+            unbracedSpecifiers.forEach((lines, i) => {
+                if (i > 0) {
+                    parts.push(", ");
+                }
+                parts.push(lines);
+            });
+
+            if (bracedSpecifiers.length > 0) {
+                let lines = fromString(", ").join(bracedSpecifiers);
+                if (lines.getLineLength(1) > options.wrapColumn) {
+                    lines = concat([
+                        fromString(",\n").join(
+                            bracedSpecifiers
+                        ).indent(options.tabWidth),
+                        ","
+                    ]);
+                }
+
+                if (unbracedSpecifiers.length > 0) {
+                    parts.push(", ");
+                }
+
+                if (lines.length > 1) {
+                    parts.push("{\n", lines, "\n}");
+                } else if (options.objectCurlySpacing) {
+                    parts.push("{ ", lines, " }");
+                } else {
+                    parts.push("{", lines, "}");
+                }
+            }
         } else {
             parts.push(
                 shouldPrintSpaces ? "{ " : "{",
